@@ -139,6 +139,7 @@ class ClientConfig:
             end to end encryption keys.
         store_sync_tokens (bool, optional): Should the client store and restore
             sync tokens.
+        custom_headers (Dict[str, str]): A dictionary of custom http headers.
 
     Raises an ImportWarning if encryption_enabled is true but the dependencies
     for encryption aren't installed.
@@ -153,6 +154,7 @@ class ClientConfig:
     store_name: str = ""
     pickle_key: str = "DEFAULT_KEY"
     store_sync_tokens: bool = False
+    custom_headers: Dict[str, str] = None
 
     def __post_init__(self):
         if not ENCRYPTION_ENABLED and self.encryption_enabled:
