@@ -435,6 +435,20 @@ class MatrixRoom:
             self.summary.invited_member_count,  # type: ignore
         )
 
+    @property
+    def joined_count(self) -> int:
+        try:
+            return self._summary_details()[1]
+        except ValueError:
+            return len(tuple(u for u in self.users.values() if not u.invited))
+
+    @property
+    def invited_count(self) -> int:
+        try:
+            return self._summary_details()[2]
+        except ValueError:
+            return len(tuple(u for u in self.users.values() if u.invited))
+
     @property
     def member_count(self) -> int:
         try:
